#
# spec file for package llmnrd
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           llmnrd
Version:        0.7
Release:        5.3
Summary:        Link-Local Multicast Resolution (LLMNR) Daemon
License:        GPL-2.0-only
Group:          System/Daemons
URL:            https://github.com/tklauser/llmnrd
Source:         https://github.com/tklauser/llmnrd/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        llmnrd.service
Source2:        llmnrd.sysconfig
Source3:        usr.sbin.llmnrd
Patch0:	harden_llmnrd.service.patch
BuildRequires:  apparmor-profiles
BuildRequires:  gcc
BuildRequires:  git-core
BuildRequires:  make

%description
llmnrd is a daemon implementing the Link-Local Multicast Name Resolution (LLMNR)
protocol according to RFC 4795. It uses the Netlink kernel interface.

llmnrd will respond to name resolution queries sent by Windows clients in
networks where no DNS server is available. It supports both IPv4 and IPv6.

%prep
%autosetup -p1

%build
export GIT_VERSION=""
export Q=""
export CFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
make prefix=%{_prefix} DESTDIR=%{buildroot} install
install -dm0755 %{buildroot}%{_fillupdir}
install -Dpm0644 %{SOURCE1} "%{buildroot}%{_unitdir}/llmnrd.service"
install -Dpm0644 %{SOURCE2} "%{buildroot}%{_fillupdir}/sysconfig.llmnrd"
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcllmnrd
install -Dpm0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/apparmor.d/usr.sbin.llmnrd

%pre
%service_add_pre llmnrd.service

%post
%service_add_post llmnrd.service
%fillup_only

%preun
%service_del_preun llmnrd.service

%postun
%service_del_postun llmnrd.service

%files
%license COPYING
%doc README.md
%{_bindir}/llmnr-query
%{_sbindir}/llmnrd
%{_sbindir}/rcllmnrd
%{_unitdir}/llmnrd.service
%{_fillupdir}/sysconfig.llmnrd
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.llmnrd
%{_mandir}/man1/llmnr-query.1%{?ext_man}
%{_mandir}/man8/llmnrd.8%{?ext_man}

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Nov 22 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Only install man-pages once
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Tue Oct  5 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_llmnrd.service.patch
  Modified:
  * llmnrd.service
* Mon Sep 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7
  * set stdout to line buffering
  * don't exit on SO_BINDTODEVICE failure
  * create pid file when daemonizing, and remove it on exit
  * add command line option to log to syslog instead of stdio
  * only async signal safe functions may be called in signal handler
  * exit gracefully on select() EINTR
* Tue Jan 29 2019 mardnh@gmx.de
- Update to version 0.6
  * Ignore queries with TC bit set in llmnrd
  * Add option to set conflict bit in llmnr-query
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sun Oct 22 2017 mardnh@gmx.de
- Update to version 0.5
  * Poll for hostname changes
  * Fix missing terminating NULL byte in llmnr-query
  * Manpages for llmnrd and llmnr-query
  * Additional compiler warnings enabled
* Fri May 26 2017 jengelh@inai.de
- Trim redundant mentions from description.
* Sat May  6 2017 mardnh@gmx.de
- Update to version 0.4
  * llmnrd: Fix hostname compare to also consider the last character.
    This fixes a problem where llmnrd running e.g. on host foobar
    would also reply to queries for host foobaz.
  * llmnrd: Avoid error message on subsequent attempts to join
    multicast group (#21).
  * llmnr-query: Allocate large enough receive buffer to avoid
    truncating LLMNR responses and printing garbage
    hostnames/addresses (#21).
  * llmnr-query: Fixes for misaligned access.
  * Remove Debian packaging as there is now an llmnrd package in
    the official Debian repository .
- Changes since 0.2
  * Merge RTNL interface event loop into main select() loop, fixes
    race condition on termination (#20)
  * No busy wait in llmnrd receive loop (#19)
  * Fixes for handling CPPFLAGS, CFLAGS and LDFLAGS as commonly
    expected (#17)
  * llmnr-query supported on Darwin (Mac OS X) and FreeBSD
  * Additional GCC warnings enabled by default
  * Various smaller fixes and updates
- Changes since 0.1
  * Add debian packaging, from Elazar Leibovich
  * Fix misaligned memory access, from Michael Evertz
  * Don't send empty AAAA responses (#10), from Tobias Klauser
  * Allow to bind to a specific network interface (#9),
    from Tobias Klauser
  * Don't enumerate and store IPv6 addresses if IPv6 is disabled
    (#8), from Tobias Klauser
- Remove patch: llmnrd-fix-cflags.diff (fixed upstream)
* Wed Aug  3 2016 mardnh@gmx.de
- Update to version 0.1
  * socket: Set TTL values as suggested in RFC 4795, section 2.5
  * llmnr-query: Set TTL values as suggested in RFC 4795, section 2.5
  * llmnr-query: Make query type ANY the default
  * llmnr-packet: Correct LLMNR RFC number
  * llmnr-query: Allow to set LLMNR transaction id
  * llmnrd: Update copyright
  * Add simple systemd service file
  * llmnrd: Increase select() timeout
  * llmnrd: Use MAXHOSTNAMELEN for hostname buffer and zero-terminate string
  * llmnr-query: Prevent read buffer overflow in response parsing
  * llmnrd v0.1
* Sun Jul 24 2016 mardnh@gmx.de
- Update to version 0.0.0.git1461922774.741f912:
  * build: Fix install targets for use with DESTDIR
  * build: travis: Set up Coverity scan
  * COPYING: Add verbatim copy of GPLv2
  * llmnrd: Add missing break in switch
  * llmnrd: Use SA_RESTART for installed signal handlers
  * iface: Use getnameinfo() to get address from struct sockaddr_storage
  * iface: Fix memory leak in error case
  * iface: Close rtnl socket if address enumeration fails
- removed patch: llmnrd-fix-destdir.diff (fixed upstream)
* Thu Nov  5 2015 mardnh@gmx.de
- initial package
